@@ -9,6 +9,7 @@ the tester via a callback message interface"""
 import typing
 
 import zigpy.zdo.types
+
 import zigpy_znp.types as t
 
 
@@ -79,12 +80,7 @@ class NullableNodeDescriptor(zigpy.zdo.types.NodeDescriptor):
 
     def serialize(self) -> bytes:
         # Special case when the node descriptor is completely empty
-        if hasattr(self, "_fields"):
-            is_empty = all(getattr(self, field) is None for field, _ in self._fields)
-        else:
-            is_empty = not self.assigned_fields()
-
-        if is_empty:
+        if not self.assigned_fields():
             return b"\x00"
 
         return super().serialize()
@@ -139,10 +135,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x02,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
         ),
         rsp_schema=t.STATUS_SCHEMA,
@@ -154,10 +154,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x03,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
         ),
         rsp_schema=t.STATUS_SCHEMA,
@@ -169,10 +173,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x04,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
             t.Param("Endpoint", t.uint8_t, "application endpoint the data is from"),
         ),
@@ -185,10 +193,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x05,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
         ),
         rsp_schema=t.STATUS_SCHEMA,
@@ -200,10 +212,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x06,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
             t.Param("ProfileId", t.uint16_t, "profile id of the device"),
             t.Param("InputClusters", t.ClusterIdList, "Input cluster id list"),
@@ -218,10 +234,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x07,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
         ),
         rsp_schema=t.STATUS_SCHEMA,
@@ -233,10 +253,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x08,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the inquiry",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the inquiry",
             ),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
         ),
         rsp_schema=t.STATUS_SCHEMA,
@@ -298,7 +322,9 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         0x20,
         req_schema=(
             t.Param(
-                "DstAddr", t.NWK, "Short address of the device generating the request",
+                "DstAddr",
+                t.NWK,
+                "Short address of the device generating the request",
             ),
             t.Param(
                 "LocalCoordinator",
@@ -533,8 +559,8 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
     )
 
     # starts the device in the network
-    # XXX: This actually just calls `bdb_StartCommissioning()` and returns `ZSuccess`.
-    #      It just happens that ZSuccess == StartupState.RestoredNetworkState == 0
+    # XXX: In Z-Stack 3, this actually just calls `bdb_StartCommissioning()` and returns
+    #  ZSuccess. It just happens that ZSuccess == StartupState.RestoredNetworkState == 0
     StartupFromApp = t.CommandDef(
         t.CommandType.SREQ,
         0x40,
@@ -837,10 +863,14 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         req_schema=(
             t.Param("NWK", t.NWK, "Short address of the destination"),
             t.Param(
-                "NWKAddrOfInterest", t.NWK, "Short address of the device being queried",
+                "NWKAddrOfInterest",
+                t.NWK,
+                "Short address of the device being queried",
             ),
             t.Param(
-                "Cmd", t.uint8_t, "A valid Cluser ID command as specified by profile",
+                "Cmd",
+                t.uint8_t,
+                "A valid Cluser ID command as specified by profile",
             ),
         ),
         rsp_schema=t.STATUS_SCHEMA,
@@ -1079,7 +1109,7 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
             t.Param(
                 "Status", t.ZDOStatus, "Status is either Success (0) or Failure (1)"
             ),
-            t.Param("Neighbours", zigpy.zdo.types.Neighbors, "Neighbours"),
+            t.Param("Neighbors", zigpy.zdo.types.Neighbors, "Neighbors"),
         ),
     )
 
@@ -1269,7 +1299,9 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
                 "NWK", t.NWK, "Short address of the source of the leave indication"
             ),
             t.Param(
-                "IEEE", t.EUI64, "IEEE address of the source of the leave indication",
+                "IEEE",
+                t.EUI64,
+                "IEEE address of the source of the leave indication",
             ),
             t.Param("Request", t.Bool, "True -- request, False -- indication"),
             t.Param("Remove", t.Bool, "True -- Remove children"),
@@ -1285,7 +1317,9 @@ class ZDO(t.CommandsBase, subsystem=t.Subsystem.ZDO):
         rsp_schema=(
             t.Param("Src", t.NWK, "Source address of the ZDO message"),
             t.Param(
-                "IsBroadcast", t.Bool, "Indicates whether the message was a broadcast",
+                "IsBroadcast",
+                t.Bool,
+                "Indicates whether the message was a broadcast",
             ),
             t.Param("ClusterId", t.ClusterId, "Cluster Id of this ZDO message"),
             t.Param("SecurityUse", t.uint8_t, "Not used"),
