@@ -6,10 +6,9 @@ import argparse
 
 import zigpy_znp.types as t
 import zigpy_znp.commands as c
-
 from zigpy_znp.api import ZNP
 from zigpy_znp.config import CONFIG_SCHEMA
-from zigpy_znp.exceptions import InvalidCommandResponse, CommandNotRecognized
+from zigpy_znp.exceptions import SecurityError, CommandNotRecognized
 from zigpy_znp.types.nvids import NwkNvIds, OsalExNvIds
 from zigpy_znp.tools.common import setup_parser
 
@@ -19,7 +18,7 @@ LOGGER = logging.getLogger(__name__)
 async def backup(radio_path):
     znp = ZNP(CONFIG_SCHEMA({"device": {"path": radio_path}}))
 
-    await znp.connect()
+    await znp.connect(check_version=False)
 
     data = {
         "osal": {},
@@ -32,9 +31,12 @@ async def backup(radio_path):
             LOGGER.info("%s = %s", nwk_nvid, value)
 
             data["nwk"][nwk_nvid.name] = value.hex()
-        except InvalidCommandResponse:
+        except KeyError:
             LOGGER.warning("Read failed for %s", nwk_nvid)
             continue
+        except SecurityError:
+            LOGGER.error("Read not allowed for %s", nwk_nvid)
+            continue
 
     try:
         # Old versions of Z-Stack do not have the OSAL NVIDs
