@@ -4,8 +4,8 @@ import logging
 import dataclasses
 
 import zigpy.zdo.types
-import zigpy_znp.types as t
 
+import zigpy_znp.types as t
 
 LOGGER = logging.getLogger(__name__)
 
@@ -407,16 +407,21 @@ class CommandBase:
         params = {}
 
         for param in cls.schema:
-            if data:
+            try:
                 params[param.name], data = param.type.deserialize(data)
-            elif not param.optional:
-                # If we're out of data but the parameter is required, this is bad
-                raise ValueError(
-                    f"Data has been consumed but required parameters remain: {param}"
-                )
-            else:
-                # If we're out of data and the parameter is optional, we're done
-                break
+            except ValueError:
+                if not data and param.optional:
+                    # If we're out of data and the parameter is optional, we're done
+                    break
+                elif not data and not param.optional:
+                    # If we're out of data but the parameter is required, this is bad
+                    raise ValueError(
+                        f"Frame data is truncated (parsed {params}),"
+                        f" required parameter remains: {param}"
+                    )
+                else:
+                    # Otherwise, let the exception happen
+                    raise
 
         if data:
             msg = (
@@ -553,11 +558,11 @@ class MTCapabilities(t.enum_flag_uint16):
 
 
 class Network(t.Struct):
-    PanId = t.PanId
-    Channel = t.uint8_t
-    StackProfileVersion = t.uint8_t
-    BeaconOrderSuperframe = t.uint8_t
-    PermitJoining = t.uint8_t
+    PanId: t.PanId
+    Channel: t.uint8_t
+    StackProfileVersion: t.uint8_t
+    BeaconOrderSuperframe: t.uint8_t
+    PermitJoining: t.uint8_t
 
 
 STATUS_SCHEMA = (
