@@ -3,11 +3,10 @@ import typing
 import logging
 import dataclasses
 
-from zigpy.types import EUI64, NWK, ExtendedPanId, PanId, ClusterId
+from zigpy.types import NWK, EUI64, PanId, KeyData, ClusterId, ExtendedPanId
 
 from . import basic, struct
 
-
 LOGGER = logging.getLogger(__name__)
 
 
@@ -272,6 +271,11 @@ class StartupOptions(basic.enum_flag_uint8):
     ClearState = 1 << 1
     AutoStart = 1 << 2
 
+    # FrameCounter should persist across factory resets.
+    # This should not be used as part of FN reset procedure.
+    # Set to reset the FrameCounter of all Nwk Security Material
+    ClearNwkFrameCounter = 1 << 7
+
 
 class DeviceLogicalType(basic.enum_uint8):
     Coordinator = 0
@@ -291,3 +295,10 @@ class ClusterIdList(basic.LVList, item_type=ClusterId, length_type=basic.uint8_t
 
 class NWKList(basic.LVList, item_type=NWK, length_type=basic.uint8_t):
     pass
+
+
+class TCLinkKey(struct.Struct):
+    ExtAddr: EUI64
+    Key: KeyData
+    TxFrameCounter: basic.uint32_t
+    RxFrameCounter: basic.uint32_t
