@@ -140,7 +140,7 @@ class ZnpMtProtocol(asyncio.Protocol):
 
         return frame
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"<{type(self).__name__} for {self._api}>"
 
 
